#' get boundary data from drwateR database
#'
#' @param uid user id of cctb database
#' @param belongtos the dplyr::filter statement of belongto
#' @param conn MySQL connection
#' @param dbdisconn disconnect the connection
#'
#' @return bounddb tibble data frame
#' @importFrom stringr str_c
#' @importFrom DBI dbListTables dbGetQuery dbDisconnect
#' @importFrom tibble as_tibble
#' @importFrom cctdb get_dbconn
#' @export
#'
get_bounddb <- function(uid,
                        belongtos = "",
                        conn = get_dbconn(gsub("^(ucc.*)$", "\\1pub", uid)),
                        dbdisconn = TRUE) {
  if (!("boundary" %in% DBI::dbListTables(conn))) {
    brk_dbconn(conn, dbdisconn)
    warning("No valid datatable found!")
    return(invisible(NULL))
  }
  selectstr <- "SELECT * FROM `boundary`"
  condstr <- ""
  belongtostr <- belongtosqlstr(belongtos)
  if (!is.null(belongtostr)) {
    condstr <- paste0(" WHERE ", belongtosqlstr(belongtos))
  }
  sqlstr <- paste0(selectstr, condstr, ";")
  bounddb <- tibble::as_tibble(DBI::dbGetQuery(conn = conn, statement = sqlstr))
  brk_dbconn(conn, dbdisconn)
  return(bounddb)
}
