#' read cell ident data from MYSQL database in RCEES
#'
#' read ident data from MYSQL database in RCEES, which is
#' generated by the Cell Counting Tool, mainly read the cell
#' counting values and taxononmy database, return a dataframe
#'
#' @param uid database User ID, provided by RCEES
#' @param daterange date range
#' @param datelim (deprecated!) date range
#' @param sites  sites
#' @param zlim water depth range of samples
#' @param reps repeat samples id
#' @param taxs taxonomy names
#' @param conn connection to database server
#' @param dbdisconn disconnect conn when finished
#' @return return a data frame with ident data.
#' @importFrom DBI dbGetQuery dbDisconnect dbListTables
#' @importFrom tibble as_tibble
#' @importFrom stringr str_c
#' @importFrom cctdb get_dbconn
#' @export
#'
get_identdb <- function(
    uid,
    daterange = "",
    sites = "",
    zlim = c(0, 100),
    reps = "",
    taxs = "",
    conn = cctdb::get_dbconn(gsub("^(ucc.*)$", "\\1pub", uid)),
    dbdisconn = TRUE,
    datelim = NULL) {
  if (!is.null(datelim)) {
    warning("'datelim' is deprecated; using 'daterange' instead!")
    daterange <- datelim
  }
  if (!("ident" %in% DBI::dbListTables(conn))) {
    brk_dbconn(conn, dbdisconn)
    warning("No valid datatable found!")
    return(invisible(NULL))
  }
  selectstr <- "SELECT * FROM `ident`"
  condstr <- "" # TODO
  sqlstr <- paste0(selectstr, condstr, ";")
  identdb <- tibble::as_tibble(DBI::dbGetQuery(conn = conn, statement = sqlstr))
  brk_dbconn(conn, dbdisconn)
  return(identdb)
}
