#' Generate a Grid of Phyla for Each Date
#'
#' This function creates a data frame containing all unique combinations
#' of dates and ordered phyla from the provided data frame.
#'
#' @param phytadf A data frame containing at least a column named `date`.
#'
#' @return A data frame with two columns: `date` and `phyta`, representing all
#'         combinations of unique dates and ordered phyla.
#'
#' @export
#' @importFrom tidyr expand_grid
#' @importFrom dplyr mutate
#'
#' @examples
#' phytagrid <- get_phytagrid(phytadf)
#'
get_phytagrid <- function(phytadf) {
  # Generate a grid of unique dates and ordered phyla
  phytagrid <- tidyr::expand_grid(
    date = unique(phytadf$date),
    phyta = get_phytaorder(phytadf)
  ) |>
    dplyr::mutate(phyta = as.character(.data$phyta)) |>
    dplyr::mutate(date = as.Date(date))
  return(phytagrid)
}
