#' get site data from drwateR database
#'
#' @param uid user id of cctb database
#' @param belongtos the dplyr::filter statement of belongto
#' @param conn MySQL connection
#' @param dbdisconn disconnect the connection
#'
#' @return sitedb tibble data frame
#' @importFrom cctdb get_dbconn
#' @importFrom DBI dbListTables dbGetQuery
#' @importFrom tibble as_tibble
#' @importFrom dplyr rename
#' @importFrom stringr str_c
#' @export
#'
get_sitedb <- function(
    uid,
    sites = "",
    belongto = "",
    conn = cctdb::get_dbconn(gsub("^(ucc.*)$", "\\1pub", uid)),
    dbdisconn = TRUE) {
  if (!("site" %in% DBI::dbListTables(conn))) {
    brk_dbconn(conn, dbdisconn)
    warning("No valid datatable found!")
    return(invisible(NULL))
  }
  selectstr <- "SELECT * FROM `site`"
  sitestr <- pidsitesqlstr(sites, type = "code")
  condstr <- ""
  if (!is.null(sitestr)) {
    condstr <- paste0(" WHERE ", sitestr)
  }
  sqlstr <- paste0(selectstr, condstr, ";")
  sitedb <- DBI::dbGetQuery(conn = conn, statement = sqlstr) |>
    tibble::as_tibble() |>
    dplyr::rename(
      site = "code",
      siteind = "ind",
      zmax = "depth"
    )
  brk_dbconn(conn, dbdisconn)
  return(sitedb)
}
