#' Get Samples Information Data
#'
#' This function extracts information about samples from the phytoplankton
#' data frame, including the number of distinct sampling dates and sites.
#'
#' @param phytodf A data frame containing phytoplankton data, which includes
#'                 columns for date and site.
#'
#' @return A data frame summarizing the number of distinct samples per date.
#'         The data frame contains two columns: `date` and `n`, where `n` is
#'         the count of distinct sites for each date.
#'
#' @importFrom dplyr ungroup select distinct count
#' @export
#'
#' @examples
#' sample_info <- get_smpdf(phytodf)
#'
get_smpdf <- function(phytodf) {
  smpdf <- phytodf |>
    dplyr::ungroup() |>
    dplyr::select("date", "site") |>
    dplyr::distinct() |>
    dplyr::count(.data$date, name = "n")
  return(smpdf)
}
