#' Get Phytoplankton Color Palette
#'
#' This function returns a color palette for various phytoplankton types.
#'
#' @return A named character vector of color strings associated with phytoplankton types.
#'
#' @importFrom grDevices rgb
#' @export
#'
#' @examples
#' phytacols <- taxcolpalette()
#' print(phytacols)
#'
taxcolpalette <- function() {
  phytacols <- c(
    "Cyanophyta"      = grDevices::rgb(0.4, 0.4, 0.9), # 蓝藻
    "Chlorophyta"     = grDevices::rgb(0.3, 0.7, 0.3), # 绿藻
    "Bacillariophyta" = grDevices::rgb(0.31, 0.31, 0.31), # 硅藻
    "Dinophyta"       = grDevices::rgb(0.55, 0.27, 0.075), # 甲藻
    "Cryptophyta"     = grDevices::rgb(0.5, 0.6, 0.1), # 隐藻
    "Chrysophyta"     = grDevices::rgb(1, 0.72, 0.06), # 金藻
    "Euglenophyta"    = grDevices::rgb(0.9, 0.07, 0.075), # 裸藻
    "Xanthophyta"     = grDevices::rgb(0.7, 0.7, 0), # 黄藻
    "Unknown"         = grDevices::rgb(1, 1, 1, 0), # 未知藻
    " "               = grDevices::rgb(1, 1, 1, 0), # 空
    "NA"              = grDevices::rgb(1, 1, 1, 0) # NA
  )
  return(phytacols)
}
