# cctda

**cctda** is an R package designed for managing and analyzing CC database (ccdb) data. This package includes functions to update site information, manipulate database entries, generate color palettes for visualizations, and more.

## Installation

You can install the `cctda` package from GitHub with the following command:

```r
drwateR::install_drwateR("cctda")
```

## Functions

### 1. `get_ccdbraw()`

Retrieve all data from the CC database.

#### Arguments

- `uid`: User ID of the CC database.

#### Returns

- `data.frame`: The raw CC database.

### 2. `set_sub()`

Check and update potentially erroneous sub-data columns.

#### Arguments

- `ccdbraw`: The raw CC database, obtained from `get_ccdbraw(uid)`.

#### Returns

- `data.frame`: The revised CC database.

### 3. `get_smpsqnodf()`

Summarize the actual count of sample grids.

#### Arguments

- `ccdbraw`: The original CC database, obtained from `get_ccdbraw(uid)`.

#### Returns

- `data.frame`: Summary of sample grid data.

### 4. `set_ccsqno()`

Check and update potentially erroneous sample number data columns.

#### Arguments

- `ccdbraw`: The CC database for checking, should come from `get_ccdbraw(uid) |> set_sub()`.
- `fn`: Excel file name for manual checks.
- `smpsqnodf`: Summarized sample data, default is `get_smpsqnodf(ccdbraw)`.
- `savetoxlsx`: Save to Excel, default is `TRUE`.

#### Returns

- `data.frame`: The revised sample grid data.

### 5. `set_celldenbio()`

Check and update potentially erroneous cell density and biomass columns.

#### Arguments

- `ccdbraw`: The raw CC database, obtained from `get_ccdbraw(uid)`.

#### Returns

- `data.frame`: The revised CC database with updated density and biomass.

### 6. `set_ccdb()`

Upload the manually reviewed CC database to the database.

#### Arguments

- `ccdbrevised`: The manually reviewed CC database.
- `uid`: User ID of the CC database.
- `conn`: Database connection for updates.
- `fn`: Excel file name for manual confirmation.

#### Returns

- `logical`: Whether the site table update was successful.

### 7. `upd_sitedb()`

Update site data in the drwateR database.

#### Arguments

- `uid`: User ID of the cctb database.
- `sitefn`: The Excel file with updated site information.
- `conn`: MySQL connection.
- `dbdisconn`: Disconnect the connection after update.

#### Returns

- `logical`: Success flag for the site table update.

### 8. `mycol()`

Generate user-defined color palettes using RColorBrewer.

#### Arguments

- `ncolor`: Number of colors to generate.
- `coltype`: Palette type (default is "Mix").
- `phytas`: Special setup for phyta.

#### Returns

- `character`: A vector of color strings.

### 9. `taxcolpalette()`

Generate a color palette for different taxonomic groups.

#### Arguments

- `phytas`: A vector of specific taxa to generate colors for.

#### Returns

- `character`: A vector of color strings specific to the provided taxa.

## Usage

Here is an example of how to use the `cctda` package:

```r
library(cctda)

# Get raw CC database
ccdbraw <- get_ccdbraw(uid = "your_uid")

# Update sub-data columns
ccdbrevised <- set_sub(ccdbraw)

# Check and update sample number data
smpsqnodf <- get_smpsqnodf(ccdbraw)
revised_ccdb <- set_ccsqno(ccdbraw, smpsqnodf = smpsqnodf)

# Upload the revised data
set_ccdb(revised_ccdb, uid = "your_uid")
```

## License

This package is licensed under the MIT License.

## Contact

For any inquiries, please contact [your_email@example.com](mailto:your_email@example.com).

```

### Notes:
- Replace `"your_username/cctda"` with your actual GitHub username and repository name.
- Fill in your email address where indicated.
- Customize the examples as necessary based on your package's intended use and features.
```
