% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_taxdb.R
\name{check_missings}
\alias{check_missings}
\title{Check for Missing Data in \code{taxdb}}
\usage{
check_missings(
  taxdb,
  fixit = TRUE,
  fn = ifelse(isTRUE(fixit), tempfile(fileext = ".xlsx"), NULL)
)
}
\arguments{
\item{taxdb}{Data frame. The taxonomic database to be checked.}

\item{fixit}{Logical. Whether to automatically fix missing values by
loading an updated Excel file. Defaults to \code{TRUE}.}

\item{fn}{Character. Temporary file name for fixing. If \code{fixit} is
\code{TRUE}, a temporary file with \code{.xlsx} extension will be created.}
}
\value{
Data frame. The original or updated \code{taxdb} with missing values
fixed if \code{fixit} is \code{TRUE}.
}
\description{
This function checks for missing values (NA) or blank entries in specified
columns of the taxonomic database (\code{taxdb}). If requested, it can also
prompt the user to fix the missing data in an Excel file.
}
\examples{
taxdb <- data.frame(
  taxen = c("Homo sapiens", NA, "Gorilla", "Pongo"),
  taxcn = c("人类", NA, "大猩猩", "红猩猩"),
  speciesen = c("sapiens", "troglodytes", "gorilla", "pygmaeus"),
  speciescn = c("人类", NA, "大猩猩", "小猩猩"),
  stringsAsFactors = FALSE
)
taxdb_fixed <- check_missings(taxdb, fixit = TRUE)
}
